% Universal Control of an Oscillator with Dispersive Coupling to a Qubit
% author
% MLS, February 2, 2015

## Oscillators are Nice

<div class="notes">
Big Hilbert space, long lived, experienced experimentalists on the 4th floor.
</div>

Especially when coupled to a spin.

. . .

Even more so if they are the relatively long lived and fast cavities you guys
are constructing on the 4th floor.


# Outline

## Outline

<div class="notes">
</div>

> - The System
> - SNAP Gate
> - State Preparation
> - Universal Control
> - Summary and Outlook

# The System and The Drives

## The System

<div class="notes">
</div>

Cavity (EM oscillator) coupled to a qubit (a two-level system)

. . .

$\hat{H}_{0}=\omega_{q}\mid e\rangle\langle e\mid+\omega_{c}\hat{n}-\chi\mid e\rangle\langle e\mid \hat{n}$

. . .

![](img/the_system_hamiltonian.png)

## The Drives - Controlling the Cavity

<div class="notes">
</div>

$\hat{H}_{cavity}=\varepsilon\left(t\right)e^{i\omega_{c}t}\hat{a}^{\dagger}+h.c.$ 

. . .

![](img/cavity_hamiltonian.png)

. . .

Displacement operator:
$\hat{D}(\alpha)=\exp\left(\alpha\hat{a}^{\dagger}-\alpha^{*}\hat{a}\right)$
where $\alpha=i\int\varepsilon(t)dt$
acting only on the ground subspace $\{\left|0\right\rangle \dots\left|n\right\rangle\dots \}\otimes\left|g\right\rangle$

## The Drives - Controlling the Qubit

<div class="notes">
</div>

$\hat{H}_{qubit}=\Omega\left(t\right)e^{i\omega_{q}t}\left|e\rangle\langle g\right|+h.c.$

. . .

![](img/qubit_hamiltonian.png)

## The Drives - Controlling the Qubit

The control can be selective on the number of photons!

. . .

$\Omega(t) = \Omega e^{-in\chi t}$ with $\Omega\ll\chi$

![](img/selective_qubit_hamiltonian.png)

## Together

<div class="notes">
</div>

$H = H_{0} + H_{cavity}(t) + H_{qubit}(t)$

# SNAP Gate

## "SNAP" Gate

<div class="notes">
</div>

Use the selective control on the qubit to take closed paths on the Bloch
sphere. **Always end in the ground state.**

. . .

![](img/snap_gate.png)

$\left|g,n\right\rangle \rightarrow e^{i\theta_{n}}\left|g,n\right\rangle$

## "SNAP" Gate

<div class="notes">
</div>

**S**elective on **N**umber **A**rbitrary **P**hase

$\hat{S}_{n}\left(\theta_{n}\right)=e^{i\theta_{n}\left|n\rangle\langle n\right|}$

## Parallel "SNAP" Gate

<div class="notes">
</div>

We can address multiple pairs of states in parallel.

$\hat{S}\left(\vec{\theta}\right)\,=\prod_{n=0}^{\infty}\hat{S}_{n}\left(\theta_{n}\right)\,=\sum_{n=0}^{\infty}e^{i\theta_{n}}\mid n\rangle\langle n\mid$

![](img/parallel_snap_gate.png)

## Restricted to the Ground State

The **usable** Hilbert space is the $\{\left|0\right\rangle \dots\left|n\right\rangle\dots \}\otimes\left|g\right\rangle$ subspace.

__For most of the rest of the presentation we will restrict ourselves to the ground subspace.__

# State Preparation

## State Preparation

<div class="notes">
</div>

We have these two basic operation acting on the ground subspace (processor
instructions in a CPU analogy):

- Displacement:

    $\hat{D}(\alpha)=\exp\left(\alpha\hat{a}^{\dagger}-\alpha^{*}\hat{a}\right)$

- SNAP Gate:

    $\hat{S}\left(\vec{\theta}\right)\,=\prod_{n=0}^{\infty}\hat{S}_{n}\left(\theta_{n}\right)\,=\sum_{n=0}^{\infty}e^{i\theta_{n}}\mid n\rangle\langle n\mid$

Both of which act only on the ground subspace.

## State Preparation

<div class="notes">
</div>

Can we use them to prepare any state in the ground subspace?

. . .

Consider $\vec{\theta}_\epsilon=(\underset{n}{\underbrace{\epsilon,\dots,\epsilon}},0,\dots)$

. . .

Sandwich the corresponding SNAP gate with a similar Displacement gate into a group commutator:

$\hat{D}(\epsilon)\hat{S}(\vec{\theta}_\epsilon)\hat{D}(-\epsilon)\hat{S}(-\vec{\theta}_\epsilon)$

. . .

$\approx \exp\left(i\epsilon^{2}\sqrt{n+1}(\mid n\rangle\langle n+1\mid+h.c.)\right)$

. . .

Nearest neighbours are coupled and by iteration we can couple all levels.

## Explicit Algorithm - n to n+1

Given the state $\left|n\right\rangle$
we want to create the state
$\left|\text{target}\right\rangle=\cos(\theta)\left|n\right\rangle + \sin(\theta)\left|n+1\right\rangle$

. . .

Inspired by the above, consider the non-infinitesimal operation:

$\hat{U}_{n}=\hat{D}(\alpha_{1})\hat{R}_{n}\hat{D}(\alpha_{2})\hat{R}_{n}\hat{D}(\alpha_{3})$

where

$\hat{R}_{n}=-\sum_{n'=0}^{n}\left|n'\rangle\langle n'\right|+\sum_{n'=n+1}^{\infty}\left|n'\rangle\langle n'\right|$

## Explicit Algorithm - n to n+1

$\hat{U}_{n}=\hat{D}(\alpha_{1})\hat{R}_{n}\hat{D}(\alpha_{2})\hat{R}_{n}\hat{D}(\alpha_{3})$

$\hat{R}_{n}=-\sum_{n'=0}^{n}\left|n'\rangle\langle n'\right|+\sum_{n'=n+1}^{\infty}\left|n'\rangle\langle n'\right|$

![](img/DRDRD.png)

## Explicit Algorithm - n to n+1

Optimize $F=\left|\left\langle\text{target}\right|\hat{U}_{n}\left|n\right\rangle\right|$
wrt $\alpha_1$, $\alpha_2$, and $\alpha_3$ with some good initial guesses.

. . .

![](img/infidielity_state_n_to_rot.png)

## Explicit Algorithm - $\mid 0\rangle$ to $\mid \psi \rangle$

Restrict to "non-negative" $\mid \psi \rangle$

$\mid \psi \rangle = \left|\text{target}\right\rangle =\sum_{n=0}^{N}c_n\left|n\right\rangle$, $\,\,\,c_n\ge 0$

. . .

Construction by "unrolling":

> - Requires $N$ runs of the previous algorithm (n to n+1) (or just a dictionary
>   lookup)
> - Optionally a "global" optimization can be run over all parameters (after
>   simplifications this means an optimization over $2N+1$ parameters)

. . .

Apply a final SNAP gate to impart any missing phases.

## Explicit Algorithm - $\mid 0\rangle$ to $\mid \psi \rangle$

Fidelity better than $0.999$.

. . .

![](img/pulse_for_sym_state_bigger.png)

## Final Cost

To create an arbitrary N-dimensional state

> - To find the pulses
>     - N optimizations over 3 parameters (or N dictionary lookups)
>     - 1 optimization over 2N+1 parameters (takes ~5seconds in practice)
> 
> - To implement the pulses
>     - 2N+1 displacement gates
>     - 2N SNAP gates

## Super Efficient Fock State Preparation

- Displace to coherent state $\mid\alpha\rangle=D(\alpha=\sqrt{n})\mid0\rangle$
- Use $\mathcal{O}(\sqrt{n})$ rotations to "fold" it into $\mid n \rangle$

![](img/sublinear_poisson.png)

## Super Efficient Fock State Preparation

![](img/sublinear_smaller.png)

# Universal Control

## Universal Control

We want to perform an arbitrary unitary operation on the oscillator state (even
when the state is unknown), not just prepare a target state from another given
state.

> - Preparing a 2x2 rotation **sub**matrix
> - Chaining 2x2 **sub**matrices into an NxN unitary matrix

## 2-by-2 Rotation Sub-Matrix

As in the case of state preparation for
$\left|n\right\rangle \rightarrow \cos(\theta)\left|n\right\rangle + \sin(\theta)\left|n+1\right\rangle$

we want to use

$\hat{U}=\hat{D}(\alpha_{1})\hat{R}_{n}\hat{D}(\alpha_{2})\hat{R}_{n}\hat{D}(\alpha_{3})$

to implement

$\hat{U}_{target}=\left[\begin{array}{c|c|c}
Id_{n\times n} & 0 & 0\\
\hline 0 & \begin{array}{cc}\cos\theta & -\sin\theta\\ \sin\theta & \cos\theta \end{array} & 0\\
\hline 0 & 0 & Id
\end{array}\right]$

on the $\{|n\rangle,|n+1\rangle\}$ subspace.

## 2-by-2 Rotation Sub-Matrix

Optimize $F=\left|\frac{1}{N_{cutoff}}Tr\left(\hat{U}^{\dagger}\hat{U}_{target}\right)\right|$
wrt $\alpha_1$ and $\alpha_2$ ($\alpha_3 = -\alpha_1-\alpha_2$)

![](img/infidelity_so2.png)

## N-by-N Unitary Matrix

We want to construct $\hat{U}_{target}$

$\hat{U}_{target}^{-1}=\left[\begin{array}{c|c}
\hat{W}_{n\times n} & 0\\
\hline 0 & Id
\end{array}\right]$

## N-by-N Unitary Matrix - Removing a Column

We can apply a SNAP gate to make the last column positive

and then chain $N-1$ 2-by-2 rotations:

$\hat{V}_{n-1,n}\dots\hat{V}_{1,2}\hat{S}_{n}\hat{U}_{target}^{-1}=\left[\begin{array}{c|c}
\begin{array}{c|c}
\hat{W}_{n-1\times n-1} & 0\\
\hline 0 & 1
\end{array} & 0\\
\hline 0 & Id
\end{array}\right]$

## N-by-N Unitary Matrix - Removing a Column

Removing a column requires $N-1$ 2-by-2 matrices. To ensure high fidelity, at the
end of the column removal we perform a global optimization over all $2N$
displacement parameters.

The cost function is the "leakage" outside of $\hat{W}_{n-1\times n-1}$

$\left[\begin{array}{c|c}
\begin{array}{c|c}
\hat{W}_{n-1\times n-1} & 0\\
\hline 0 & 1
\end{array} & 0\\
\hline 0 & Id
\end{array}\right]$

## N-by-N Unitary Matrix

We repeat the procedure for all columns. Then we do one final global
optimization over all the displacement coefficients (~$N^2$ of them) against
the fidelity

$F=\left|\frac{1}{N_{cutoff}}Tr\left(\hat{U}^{\dagger}\hat{U}_{target}\right)\right|$

## N-by-N Unitary Matrix

Target: permutation matrix

![](img/un_init.png)

## N-by-N Unitary Matrix

Result: $\hat{U}_{target}\hat{U}_{constructed}^{-1}$

![](img/un_final.png)

## N-by-N Unitary Matrix

Fidelity for random matrices:

![](img/fidelities_global_local_random.png)

## N-by-N Unitary Matrix

Fidelity for Fourier and Permutation matrices:

![](img/fidelities_global_local_fourier_permutation.png)

## Pulses for 6-by-6 Fourier matrix:

![](img/6x6_DFT_mat_pulses_bigger_label.png)

## Pulses for 6-by-6 permutation matrix:

![](img/6x6_perm_mat_pulses_bigger_label.png)

## Final Cost

To create an arbitrary N-by-N unitary matrix

> - To find the pulses (takes <5 minutes in practice)
>     - $\frac{(N-1)N}{2}$ optimizations over 3 parameters (or dictionary lookups)
>     - $N-1$ optimization over 2N+1 parameters or less
>     - $1$ optimization over $\approx N^2$ parameters
> 
> - To implement the pulses
>     - $\frac{(N-1)N}{2}$ rotations (each is 3 displacements and 2 SNAPs)
>     - $N-1$ additional SNAPs

## Universal Control and Universal Computation

> - Constructing Arbitrary State
>     - (efficient)
> - Performing Arbitrary Unitary
>     - (efficient)
> - Encoding Qubits in the Hilbert Space
>     - (can be exponentially expensive)

. . .

Efficient scheme to control a multi-level system that can store multiple qubits
of information.

## Asymptotic Fidelity

Look at small $\theta$:

![](img/infidelity_so2.png)

## Asymptotic Fidelity

For certain elegant definition of infidelity:

> - $\text{infid}\left(U_{target}\right)=\left\Vert U_{target}-U_{realization}\right\Vert $
> - where for any $M$, $\left\Vert M\right\Vert =\underset{\left\Vert \left|\psi\right\rangle \right\Vert _{2}=1}{\sup}\left\Vert M\left|\psi\right\rangle \right\Vert _{2}$

. . .

We can prove

$\text{infid}\left(U_{N\times N}\right)\le M\left(\frac{N}{n_{snaps\ per\ SO(2)}}\right)^{2}$

## Asymptotic Fidelity

Given that $\text{#gates} \propto n_{snaps\ per\ SO(2)} N^2$:

. . .

$\text{#gates} \propto \frac{N^3}{\sqrt{\text{infid}}}$

# Conclusion

## Conclusion

> - Efficient State Preparation
>     - Including an Optimization for Fock States
> - Efficient Universal Control
>     - Satisfactory at "first-pass" level
>     - Remains Efficient in the Asymptotic Regime
> - People are Already Implementing it on the 4th Floor

# Off-topic Topics

## Sublinear Preparation of "Sparse" States

The preparation of Fock states by folding can be generalized to the preparation
of any "sparse" state where the population is centered around a single Fock
state.

## Universal Control Including the Spin

We were working on only half the Hilbert space (the $\mid g \rangle$ subspace).

. . .

If we can:

> - Switch $\chi$ on and off both for the ground and for the excited state.
> - Add a $\hat{\sigma}_z \mid n \rangle\langle n \mid$ term to the Hamiltonian on command.

. . .

We can easily extend the protocol to work on the entire Hilbert space.

## Efficient Readout Scheme

Ask Chao (MLS, Mar 30, 2015) and Reinier (MLS, next week).

Implementing a binary search for a Fock state using a SNAP-like gate and
conditional measurement.

## Experimental Implementation

Reinier will be presenting it next week. They are designing even
shorter pulses with some in-depth numerical optimizations.

![](img/smbc_small.png)

# Actual Conclusion

## Actual Conclusion

Efficient, Fast and Extendable New Protocol for Universal Control

. . .

Thank you for your attention!

Questions?

(image credit to SMBC comics)

# JC

## State Preparation in JC

<div class="notes">
</div>

![](img/JC_hamiltonian.png)

$H = -\frac{1}{2}\Delta\hat{\sigma}_z + H_{green} + H_{blue}$

$H_{green} = \frac{1}{2}g(e^{i\beta}\hat{a}^\dagger\hat{\sigma}_- + h.c.)$

$H_{blue} = \frac{1}{2}\chi(\cos\phi\hat{\sigma}_x + \sin\phi\hat{\sigma}_y)$

C. K. Law and J. H. Eberly, Phys. Rev. Lett. 76, 1055 (1996)

## Universal Control in JC

<div class="notes">
</div>

Their SNAP-like gate is very expensive (they do provide faster non-analytic
version).

$T_{total}\propto \frac{N^{18.5}}{\text{infid}^3}$

Brian Mischuck and Klaus Mølmer, Phys. Rev. A 87, 022341 (2013)

